# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
    EnumDescriptor as google___protobuf___descriptor___EnumDescriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from typing import (
    List as typing___List,
    Optional as typing___Optional,
    Tuple as typing___Tuple,
    Union as typing___Union,
    cast as typing___cast,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
builtin___str = str
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class LedgerSpecifier(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    class Shortcut(builtin___int):
        DESCRIPTOR: google___protobuf___descriptor___EnumDescriptor = ...
        @classmethod
        def Name(cls, number: builtin___int) -> builtin___str: ...
        @classmethod
        def Value(cls, name: builtin___str) -> 'LedgerSpecifier.Shortcut': ...
        @classmethod
        def keys(cls) -> typing___List[builtin___str]: ...
        @classmethod
        def values(cls) -> typing___List['LedgerSpecifier.Shortcut']: ...
        @classmethod
        def items(cls) -> typing___List[typing___Tuple[builtin___str, 'LedgerSpecifier.Shortcut']]: ...
        SHORTCUT_UNSPECIFIED = typing___cast('LedgerSpecifier.Shortcut', 0)
        SHORTCUT_VALIDATED = typing___cast('LedgerSpecifier.Shortcut', 1)
        SHORTCUT_CLOSED = typing___cast('LedgerSpecifier.Shortcut', 2)
        SHORTCUT_CURRENT = typing___cast('LedgerSpecifier.Shortcut', 3)
    SHORTCUT_UNSPECIFIED = typing___cast('LedgerSpecifier.Shortcut', 0)
    SHORTCUT_VALIDATED = typing___cast('LedgerSpecifier.Shortcut', 1)
    SHORTCUT_CLOSED = typing___cast('LedgerSpecifier.Shortcut', 2)
    SHORTCUT_CURRENT = typing___cast('LedgerSpecifier.Shortcut', 3)

    shortcut = ... # type: LedgerSpecifier.Shortcut
    sequence = ... # type: builtin___int
    hash = ... # type: builtin___bytes

    def __init__(self,
        *,
        shortcut : typing___Optional[LedgerSpecifier.Shortcut] = None,
        sequence : typing___Optional[builtin___int] = None,
        hash : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LedgerSpecifier: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LedgerSpecifier: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"hash",u"ledger",u"sequence",u"shortcut"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"hash",u"ledger",u"sequence",u"shortcut"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"hash",b"hash",u"ledger",b"ledger",u"sequence",b"sequence",u"shortcut",b"shortcut"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"hash",b"hash",u"ledger",b"ledger",u"sequence",b"sequence",u"shortcut",b"shortcut"]) -> None: ...
    def WhichOneof(self, oneof_group: typing_extensions___Literal[u"ledger",b"ledger"]) -> typing_extensions___Literal["shortcut","sequence","hash"]: ...

class LedgerRange(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    ledger_index_min = ... # type: builtin___int
    ledger_index_max = ... # type: builtin___int

    def __init__(self,
        *,
        ledger_index_min : typing___Optional[builtin___int] = None,
        ledger_index_max : typing___Optional[builtin___int] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> LedgerRange: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> LedgerRange: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"ledger_index_max",u"ledger_index_min"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"ledger_index_max",b"ledger_index_max",u"ledger_index_min",b"ledger_index_min"]) -> None: ...



import typing as t

import nacl.encoding
import nacl.signing

from xpring import hashes
from xpring.algorithms.signing import Seed, PrivateKey, PublicKey, Signature

SEED_PREFIX = b'\x01\xE1\x4B'
"""
For some reason, the team wanted public keys to be a uniform 33 bytes.
ed25519 public keys are only 32 bytes, so they are given a 1-byte prefix.
"""
KEY_PREFIX = b'\xED'


# https://xrpl.org/cryptographic-keys.html#ed25519-key-derivation
def derive_key_pair(seed: Seed) -> t.Tuple[PrivateKey, PublicKey]:
    private_key = hashes.sha512half(seed)
    public_key = nacl.signing.SigningKey(private_key).verify_key._key[:32]  # pylint: disable=protected-access
    return (
        t.cast(PrivateKey, private_key),
        t.cast(PublicKey, KEY_PREFIX + public_key),
    )


def sign(message: bytes, private_key: PrivateKey) -> Signature:
    assert len(private_key) == 32
    key = nacl.signing.SigningKey(private_key)
    signature = key.sign(message, nacl.encoding.RawEncoder).signature
    return t.cast(Signature, signature)


def verify(message: bytes, signature: Signature, public_key: PublicKey) -> bool:
    assert len(public_key) == 33
    assert public_key.startswith(KEY_PREFIX)
    key = nacl.signing.VerifyKey(public_key[len(KEY_PREFIX):])
    return key.verify(message, signature, nacl.encoding.RawEncoder) == message



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/ledger_objects.proto

from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import common_pb2 as org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/ledger_objects.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n$org/xrpl/rpc/v1/ledger_objects.proto\x12\x0forg.xrpl.rpc.v1\x1a\x1corg/xrpl/rpc/v1/common.proto\"\x86\x05\n\x0cLedgerObject\x12\x34\n\x0c\x61\x63\x63ount_root\x18\x01 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.AccountRootH\x00\x12\x31\n\namendments\x18\x02 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.AmendmentsH\x00\x12\'\n\x05\x63heck\x18\x03 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.CheckH\x00\x12@\n\x0f\x64\x65posit_preauth\x18\x04 \x01(\x0b\x32%.org.xrpl.rpc.v1.DepositPreauthObjectH\x00\x12\x38\n\x0e\x64irectory_node\x18\x05 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.DirectoryNodeH\x00\x12)\n\x06\x65scrow\x18\x06 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.EscrowH\x00\x12\x34\n\x0c\x66\x65\x65_settings\x18\x07 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.FeeSettingsH\x00\x12\x36\n\rledger_hashes\x18\x08 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LedgerHashesH\x00\x12\'\n\x05offer\x18\t \x01(\x0b\x32\x16.org.xrpl.rpc.v1.OfferH\x00\x12\x32\n\x0bpay_channel\x18\n \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.PayChannelH\x00\x12\x34\n\x0cripple_state\x18\x0b \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.RippleStateH\x00\x12\x32\n\x0bsigner_list\x18\x0c \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.SignerListH\x00\x42\x08\n\x06object\"\xfc\x05\n\x0b\x41\x63\x63ountRoot\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12)\n\x07\x62\x61lance\x18\x02 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Balance\x12+\n\x08sequence\x18\x03 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Sequence\x12%\n\x05\x66lags\x18\x04 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12\x30\n\x0bowner_count\x18\x05 \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.OwnerCount\x12G\n\x17previous_transaction_id\x18\x06 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x07 \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\x12\x45\n\x16\x61\x63\x63ount_transaction_id\x18\x08 \x01(\x0b\x32%.org.xrpl.rpc.v1.AccountTransactionID\x12\'\n\x06\x64omain\x18\t \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Domain\x12.\n\nemail_hash\x18\n \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.EmailHash\x12\x30\n\x0bmessage_key\x18\x0b \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.MessageKey\x12\x30\n\x0bregular_key\x18\x0c \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.RegularKey\x12,\n\ttick_size\x18\r \x01(\x0b\x32\x19.org.xrpl.rpc.v1.TickSize\x12\x34\n\rtransfer_rate\x18\x0e \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.TransferRate\"\xba\x02\n\nAmendments\x12\x39\n\namendments\x18\x01 \x03(\x0b\x32%.org.xrpl.rpc.v1.Amendments.Amendment\x12\x38\n\nmajorities\x18\x02 \x03(\x0b\x32$.org.xrpl.rpc.v1.Amendments.Majority\x12%\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x1a\x1a\n\tAmendment\x12\r\n\x05value\x18\x01 \x01(\x0c\x1at\n\x08Majority\x12\x38\n\tamendment\x18\x01 \x01(\x0b\x32%.org.xrpl.rpc.v1.Amendments.Amendment\x12.\n\nclose_time\x18\x02 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.CloseTime\"\xc7\x05\n\x05\x43heck\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12%\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12.\n\nowner_node\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.OwnerNode\x12G\n\x17previous_transaction_id\x18\x05 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x06 \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\x12*\n\x08send_max\x18\x07 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.SendMax\x12+\n\x08sequence\x18\x08 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Sequence\x12:\n\x10\x64\x65stination_node\x18\t \x01(\x0b\x32 .org.xrpl.rpc.v1.DestinationNode\x12\x38\n\x0f\x64\x65stination_tag\x18\n \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\x12/\n\nexpiration\x18\x0b \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\x12.\n\ninvoice_id\x18\x0c \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.InvoiceID\x12.\n\nsource_tag\x18\r \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.SourceTag\"\xf2\x02\n\x14\x44\x65positPreauthObject\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12-\n\tauthorize\x18\x02 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.Authorize\x12%\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12.\n\nowner_node\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.OwnerNode\x12G\n\x17previous_transaction_id\x18\x05 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x06 \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\"\x99\x04\n\rDirectoryNode\x12%\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12.\n\nroot_index\x18\x02 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.RootIndex\x12\'\n\x07indexes\x18\x03 \x03(\x0b\x32\x16.org.xrpl.rpc.v1.Index\x12.\n\nindex_next\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.IndexNext\x12\x36\n\x0eindex_previous\x18\x05 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.IndexPrevious\x12%\n\x05owner\x18\x06 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Owner\x12?\n\x13taker_pays_currency\x18\x07 \x01(\x0b\x32\".org.xrpl.rpc.v1.TakerPaysCurrency\x12;\n\x11taker_pays_issuer\x18\x08 \x01(\x0b\x32 .org.xrpl.rpc.v1.TakerPaysIssuer\x12>\n\x13taker_gets_currency\x18\t \x01(\x0b\x32!.org.xrpl.rpc.v1.TakerGetsCurreny\x12;\n\x11taker_gets_issuer\x18\n \x01(\x0b\x32 .org.xrpl.rpc.v1.TakerGetsIssuer\"\xce\x05\n\x06\x45scrow\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12\'\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12-\n\tcondition\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.Condition\x12\x32\n\x0c\x63\x61ncel_after\x18\x05 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CancelAfter\x12\x32\n\x0c\x66inish_after\x18\x06 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.FinishAfter\x12%\n\x05\x66lags\x18\x07 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12.\n\nsource_tag\x18\x08 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.SourceTag\x12\x38\n\x0f\x64\x65stination_tag\x18\t \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\x12.\n\nowner_node\x18\n \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.OwnerNode\x12:\n\x10\x64\x65stination_node\x18\x0b \x01(\x0b\x32 .org.xrpl.rpc.v1.DestinationNode\x12G\n\x17previous_transaction_id\x18\x0c \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\r \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\"\x93\x02\n\x0b\x46\x65\x65Settings\x12*\n\x08\x62\x61se_fee\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.BaseFee\x12?\n\x13reference_fee_units\x18\x02 \x01(\x0b\x32\".org.xrpl.rpc.v1.ReferenceFeeUnits\x12\x32\n\x0creserve_base\x18\x03 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.ReserveBase\x12<\n\x11reserve_increment\x18\x04 \x01(\x0b\x32!.org.xrpl.rpc.v1.ReserveIncrement\x12%\n\x05\x66lags\x18\x05 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\"\x9f\x01\n\x0cLedgerHashes\x12\x41\n\x14last_ledger_sequence\x18\x01 \x01(\x0b\x32#.org.xrpl.rpc.v1.LastLedgerSequence\x12%\n\x06hashes\x18\x02 \x03(\x0b\x32\x15.org.xrpl.rpc.v1.Hash\x12%\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\"\xd8\x04\n\x05Offer\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12+\n\x08sequence\x18\x02 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.Sequence\x12%\n\x05\x66lags\x18\x03 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12.\n\ntaker_pays\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.TakerPays\x12.\n\ntaker_gets\x18\x05 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.TakerGets\x12\x36\n\x0e\x62ook_directory\x18\x06 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.BookDirectory\x12,\n\tbook_node\x18\x07 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.BookNode\x12.\n\nowner_node\x18\x08 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.OwnerNode\x12/\n\nexpiration\x18\t \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\x12G\n\x17previous_transaction_id\x18\n \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x0b \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\"\xf3\x05\n\nPayChannel\x12)\n\x07\x61\x63\x63ount\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Account\x12\x31\n\x0b\x64\x65stination\x18\x02 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.Destination\x12\'\n\x06\x61mount\x18\x03 \x01(\x0b\x32\x17.org.xrpl.rpc.v1.Amount\x12)\n\x07\x62\x61lance\x18\x04 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Balance\x12.\n\npublic_key\x18\x05 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.PublicKey\x12\x32\n\x0csettle_delay\x18\x06 \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.SettleDelay\x12.\n\nowner_node\x18\x07 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.OwnerNode\x12G\n\x17previous_transaction_id\x18\x08 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\t \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\x12%\n\x05\x66lags\x18\n \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12/\n\nexpiration\x18\x0b \x01(\x0b\x32\x1b.org.xrpl.rpc.v1.Expiration\x12\x32\n\x0c\x63\x61ncel_after\x18\x0c \x01(\x0b\x32\x1c.org.xrpl.rpc.v1.CancelAfter\x12.\n\nsource_tag\x18\r \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.SourceTag\x12\x38\n\x0f\x64\x65stination_tag\x18\x0e \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.DestinationTag\"\xa6\x05\n\x0bRippleState\x12)\n\x07\x62\x61lance\x18\x01 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.Balance\x12%\n\x05\x66lags\x18\x02 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12,\n\tlow_limit\x18\x03 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.LowLimit\x12.\n\nhigh_limit\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.HighLimit\x12*\n\x08low_node\x18\x05 \x01(\x0b\x32\x18.org.xrpl.rpc.v1.LowNode\x12,\n\thigh_node\x18\x06 \x01(\x0b\x32\x19.org.xrpl.rpc.v1.HighNode\x12\x35\n\x0elow_quality_in\x18\x07 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.LowQualityIn\x12\x37\n\x0flow_quality_out\x18\x08 \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.LowQualityOut\x12\x37\n\x0fhigh_quality_in\x18\t \x01(\x0b\x32\x1e.org.xrpl.rpc.v1.HighQualityIn\x12\x39\n\x10high_quality_out\x18\n \x01(\x0b\x32\x1f.org.xrpl.rpc.v1.HighQualityOut\x12G\n\x17previous_transaction_id\x18\x0b \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x0c \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\"\xb1\x03\n\nSignerList\x12%\n\x05\x66lags\x18\x01 \x01(\x0b\x32\x16.org.xrpl.rpc.v1.Flags\x12G\n\x17previous_transaction_id\x18\x02 \x01(\x0b\x32&.org.xrpl.rpc.v1.PreviousTransactionID\x12`\n$previous_transaction_ledger_sequence\x18\x03 \x01(\x0b\x32\x32.org.xrpl.rpc.v1.PreviousTransactionLedgerSequence\x12.\n\nowner_node\x18\x04 \x01(\x0b\x32\x1a.org.xrpl.rpc.v1.OwnerNode\x12\x34\n\x0esigner_entries\x18\x05 \x03(\x0b\x32\x1c.org.xrpl.rpc.v1.SignerEntry\x12\x35\n\x0esigner_list_id\x18\x06 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.SignerListID\x12\x34\n\rsigner_quorum\x18\x07 \x01(\x0b\x32\x1d.org.xrpl.rpc.v1.SignerQuorum*\xd2\x03\n\x0fLedgerEntryType\x12!\n\x1dLEDGER_ENTRY_TYPE_UNSPECIFIED\x10\x00\x12\"\n\x1eLEDGER_ENTRY_TYPE_ACCOUNT_ROOT\x10\x01\x12 \n\x1cLEDGER_ENTRY_TYPE_AMENDMENTS\x10\x02\x12\x1b\n\x17LEDGER_ENTRY_TYPE_CHECK\x10\x03\x12%\n!LEDGER_ENTRY_TYPE_DEPOSIT_PREAUTH\x10\x04\x12$\n LEDGER_ENTRY_TYPE_DIRECTORY_NODE\x10\x05\x12\x1c\n\x18LEDGER_ENTRY_TYPE_ESCROW\x10\x06\x12\"\n\x1eLEDGER_ENTRY_TYPE_FEE_SETTINGS\x10\x07\x12#\n\x1fLEDGER_ENTRY_TYPE_LEDGER_HASHES\x10\x08\x12\x1b\n\x17LEDGER_ENTRY_TYPE_OFFER\x10\t\x12!\n\x1dLEDGER_ENTRY_TYPE_PAY_CHANNEL\x10\n\x12\"\n\x1eLEDGER_ENTRY_TYPE_RIPPLE_STATE\x10\x0b\x12!\n\x1dLEDGER_ENTRY_TYPE_SIGNER_LIST\x10\x0c\x42\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
  ,
  dependencies=[org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2.DESCRIPTOR,])

_LEDGERENTRYTYPE = _descriptor.EnumDescriptor(
  name='LedgerEntryType',
  full_name='org.xrpl.rpc.v1.LedgerEntryType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_ACCOUNT_ROOT', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_AMENDMENTS', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_CHECK', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_DEPOSIT_PREAUTH', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_DIRECTORY_NODE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_ESCROW', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_FEE_SETTINGS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_LEDGER_HASHES', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_OFFER', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_PAY_CHANNEL', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_RIPPLE_STATE', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LEDGER_ENTRY_TYPE_SIGNER_LIST', index=12, number=12,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=7087,
  serialized_end=7553,
)
_sym_db.RegisterEnumDescriptor(_LEDGERENTRYTYPE)

LedgerEntryType = enum_type_wrapper.EnumTypeWrapper(_LEDGERENTRYTYPE)
LEDGER_ENTRY_TYPE_UNSPECIFIED = 0
LEDGER_ENTRY_TYPE_ACCOUNT_ROOT = 1
LEDGER_ENTRY_TYPE_AMENDMENTS = 2
LEDGER_ENTRY_TYPE_CHECK = 3
LEDGER_ENTRY_TYPE_DEPOSIT_PREAUTH = 4
LEDGER_ENTRY_TYPE_DIRECTORY_NODE = 5
LEDGER_ENTRY_TYPE_ESCROW = 6
LEDGER_ENTRY_TYPE_FEE_SETTINGS = 7
LEDGER_ENTRY_TYPE_LEDGER_HASHES = 8
LEDGER_ENTRY_TYPE_OFFER = 9
LEDGER_ENTRY_TYPE_PAY_CHANNEL = 10
LEDGER_ENTRY_TYPE_RIPPLE_STATE = 11
LEDGER_ENTRY_TYPE_SIGNER_LIST = 12



_LEDGEROBJECT = _descriptor.Descriptor(
  name='LedgerObject',
  full_name='org.xrpl.rpc.v1.LedgerObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_root', full_name='org.xrpl.rpc.v1.LedgerObject.account_root', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amendments', full_name='org.xrpl.rpc.v1.LedgerObject.amendments', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='check', full_name='org.xrpl.rpc.v1.LedgerObject.check', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deposit_preauth', full_name='org.xrpl.rpc.v1.LedgerObject.deposit_preauth', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='directory_node', full_name='org.xrpl.rpc.v1.LedgerObject.directory_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='escrow', full_name='org.xrpl.rpc.v1.LedgerObject.escrow', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fee_settings', full_name='org.xrpl.rpc.v1.LedgerObject.fee_settings', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_hashes', full_name='org.xrpl.rpc.v1.LedgerObject.ledger_hashes', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offer', full_name='org.xrpl.rpc.v1.LedgerObject.offer', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pay_channel', full_name='org.xrpl.rpc.v1.LedgerObject.pay_channel', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ripple_state', full_name='org.xrpl.rpc.v1.LedgerObject.ripple_state', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_list', full_name='org.xrpl.rpc.v1.LedgerObject.signer_list', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='object', full_name='org.xrpl.rpc.v1.LedgerObject.object',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=88,
  serialized_end=734,
)


_ACCOUNTROOT = _descriptor.Descriptor(
  name='AccountRoot',
  full_name='org.xrpl.rpc.v1.AccountRoot',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.AccountRoot.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance', full_name='org.xrpl.rpc.v1.AccountRoot.balance', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.AccountRoot.sequence', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.AccountRoot.flags', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_count', full_name='org.xrpl.rpc.v1.AccountRoot.owner_count', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.AccountRoot.previous_transaction_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.AccountRoot.previous_transaction_ledger_sequence', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='account_transaction_id', full_name='org.xrpl.rpc.v1.AccountRoot.account_transaction_id', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='domain', full_name='org.xrpl.rpc.v1.AccountRoot.domain', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='email_hash', full_name='org.xrpl.rpc.v1.AccountRoot.email_hash', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='message_key', full_name='org.xrpl.rpc.v1.AccountRoot.message_key', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='regular_key', full_name='org.xrpl.rpc.v1.AccountRoot.regular_key', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tick_size', full_name='org.xrpl.rpc.v1.AccountRoot.tick_size', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transfer_rate', full_name='org.xrpl.rpc.v1.AccountRoot.transfer_rate', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=737,
  serialized_end=1501,
)


_AMENDMENTS_AMENDMENT = _descriptor.Descriptor(
  name='Amendment',
  full_name='org.xrpl.rpc.v1.Amendments.Amendment',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='org.xrpl.rpc.v1.Amendments.Amendment.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1674,
  serialized_end=1700,
)

_AMENDMENTS_MAJORITY = _descriptor.Descriptor(
  name='Majority',
  full_name='org.xrpl.rpc.v1.Amendments.Majority',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amendment', full_name='org.xrpl.rpc.v1.Amendments.Majority.amendment', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='close_time', full_name='org.xrpl.rpc.v1.Amendments.Majority.close_time', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1702,
  serialized_end=1818,
)

_AMENDMENTS = _descriptor.Descriptor(
  name='Amendments',
  full_name='org.xrpl.rpc.v1.Amendments',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='amendments', full_name='org.xrpl.rpc.v1.Amendments.amendments', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='majorities', full_name='org.xrpl.rpc.v1.Amendments.majorities', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.Amendments.flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_AMENDMENTS_AMENDMENT, _AMENDMENTS_MAJORITY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1504,
  serialized_end=1818,
)


_CHECK = _descriptor.Descriptor(
  name='Check',
  full_name='org.xrpl.rpc.v1.Check',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.Check.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.Check.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.Check.flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_node', full_name='org.xrpl.rpc.v1.Check.owner_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.Check.previous_transaction_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.Check.previous_transaction_ledger_sequence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='send_max', full_name='org.xrpl.rpc.v1.Check.send_max', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.Check.sequence', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_node', full_name='org.xrpl.rpc.v1.Check.destination_node', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.Check.destination_tag', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.Check.expiration', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='invoice_id', full_name='org.xrpl.rpc.v1.Check.invoice_id', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_tag', full_name='org.xrpl.rpc.v1.Check.source_tag', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1821,
  serialized_end=2532,
)


_DEPOSITPREAUTHOBJECT = _descriptor.Descriptor(
  name='DepositPreauthObject',
  full_name='org.xrpl.rpc.v1.DepositPreauthObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.DepositPreauthObject.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorize', full_name='org.xrpl.rpc.v1.DepositPreauthObject.authorize', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.DepositPreauthObject.flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_node', full_name='org.xrpl.rpc.v1.DepositPreauthObject.owner_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.DepositPreauthObject.previous_transaction_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.DepositPreauthObject.previous_transaction_ledger_sequence', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2535,
  serialized_end=2905,
)


_DIRECTORYNODE = _descriptor.Descriptor(
  name='DirectoryNode',
  full_name='org.xrpl.rpc.v1.DirectoryNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.DirectoryNode.flags', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_index', full_name='org.xrpl.rpc.v1.DirectoryNode.root_index', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='indexes', full_name='org.xrpl.rpc.v1.DirectoryNode.indexes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_next', full_name='org.xrpl.rpc.v1.DirectoryNode.index_next', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index_previous', full_name='org.xrpl.rpc.v1.DirectoryNode.index_previous', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner', full_name='org.xrpl.rpc.v1.DirectoryNode.owner', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_pays_currency', full_name='org.xrpl.rpc.v1.DirectoryNode.taker_pays_currency', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_pays_issuer', full_name='org.xrpl.rpc.v1.DirectoryNode.taker_pays_issuer', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_gets_currency', full_name='org.xrpl.rpc.v1.DirectoryNode.taker_gets_currency', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_gets_issuer', full_name='org.xrpl.rpc.v1.DirectoryNode.taker_gets_issuer', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2908,
  serialized_end=3445,
)


_ESCROW = _descriptor.Descriptor(
  name='Escrow',
  full_name='org.xrpl.rpc.v1.Escrow',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.Escrow.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.Escrow.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.Escrow.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='condition', full_name='org.xrpl.rpc.v1.Escrow.condition', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_after', full_name='org.xrpl.rpc.v1.Escrow.cancel_after', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='finish_after', full_name='org.xrpl.rpc.v1.Escrow.finish_after', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.Escrow.flags', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_tag', full_name='org.xrpl.rpc.v1.Escrow.source_tag', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.Escrow.destination_tag', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_node', full_name='org.xrpl.rpc.v1.Escrow.owner_node', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_node', full_name='org.xrpl.rpc.v1.Escrow.destination_node', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.Escrow.previous_transaction_id', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.Escrow.previous_transaction_ledger_sequence', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3448,
  serialized_end=4166,
)


_FEESETTINGS = _descriptor.Descriptor(
  name='FeeSettings',
  full_name='org.xrpl.rpc.v1.FeeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='base_fee', full_name='org.xrpl.rpc.v1.FeeSettings.base_fee', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reference_fee_units', full_name='org.xrpl.rpc.v1.FeeSettings.reference_fee_units', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reserve_base', full_name='org.xrpl.rpc.v1.FeeSettings.reserve_base', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reserve_increment', full_name='org.xrpl.rpc.v1.FeeSettings.reserve_increment', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.FeeSettings.flags', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4169,
  serialized_end=4444,
)


_LEDGERHASHES = _descriptor.Descriptor(
  name='LedgerHashes',
  full_name='org.xrpl.rpc.v1.LedgerHashes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='last_ledger_sequence', full_name='org.xrpl.rpc.v1.LedgerHashes.last_ledger_sequence', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hashes', full_name='org.xrpl.rpc.v1.LedgerHashes.hashes', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.LedgerHashes.flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4447,
  serialized_end=4606,
)


_OFFER = _descriptor.Descriptor(
  name='Offer',
  full_name='org.xrpl.rpc.v1.Offer',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.Offer.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.Offer.sequence', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.Offer.flags', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_pays', full_name='org.xrpl.rpc.v1.Offer.taker_pays', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='taker_gets', full_name='org.xrpl.rpc.v1.Offer.taker_gets', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='book_directory', full_name='org.xrpl.rpc.v1.Offer.book_directory', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='book_node', full_name='org.xrpl.rpc.v1.Offer.book_node', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_node', full_name='org.xrpl.rpc.v1.Offer.owner_node', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.Offer.expiration', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.Offer.previous_transaction_id', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.Offer.previous_transaction_ledger_sequence', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4609,
  serialized_end=5209,
)


_PAYCHANNEL = _descriptor.Descriptor(
  name='PayChannel',
  full_name='org.xrpl.rpc.v1.PayChannel',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account', full_name='org.xrpl.rpc.v1.PayChannel.account', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='org.xrpl.rpc.v1.PayChannel.destination', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='amount', full_name='org.xrpl.rpc.v1.PayChannel.amount', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='balance', full_name='org.xrpl.rpc.v1.PayChannel.balance', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='org.xrpl.rpc.v1.PayChannel.public_key', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='settle_delay', full_name='org.xrpl.rpc.v1.PayChannel.settle_delay', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_node', full_name='org.xrpl.rpc.v1.PayChannel.owner_node', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.PayChannel.previous_transaction_id', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.PayChannel.previous_transaction_ledger_sequence', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.PayChannel.flags', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expiration', full_name='org.xrpl.rpc.v1.PayChannel.expiration', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cancel_after', full_name='org.xrpl.rpc.v1.PayChannel.cancel_after', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source_tag', full_name='org.xrpl.rpc.v1.PayChannel.source_tag', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_tag', full_name='org.xrpl.rpc.v1.PayChannel.destination_tag', index=13,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5212,
  serialized_end=5967,
)


_RIPPLESTATE = _descriptor.Descriptor(
  name='RippleState',
  full_name='org.xrpl.rpc.v1.RippleState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='balance', full_name='org.xrpl.rpc.v1.RippleState.balance', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.RippleState.flags', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low_limit', full_name='org.xrpl.rpc.v1.RippleState.low_limit', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high_limit', full_name='org.xrpl.rpc.v1.RippleState.high_limit', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low_node', full_name='org.xrpl.rpc.v1.RippleState.low_node', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high_node', full_name='org.xrpl.rpc.v1.RippleState.high_node', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low_quality_in', full_name='org.xrpl.rpc.v1.RippleState.low_quality_in', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='low_quality_out', full_name='org.xrpl.rpc.v1.RippleState.low_quality_out', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high_quality_in', full_name='org.xrpl.rpc.v1.RippleState.high_quality_in', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='high_quality_out', full_name='org.xrpl.rpc.v1.RippleState.high_quality_out', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.RippleState.previous_transaction_id', index=10,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.RippleState.previous_transaction_ledger_sequence', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5970,
  serialized_end=6648,
)


_SIGNERLIST = _descriptor.Descriptor(
  name='SignerList',
  full_name='org.xrpl.rpc.v1.SignerList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='org.xrpl.rpc.v1.SignerList.flags', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_id', full_name='org.xrpl.rpc.v1.SignerList.previous_transaction_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='previous_transaction_ledger_sequence', full_name='org.xrpl.rpc.v1.SignerList.previous_transaction_ledger_sequence', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='owner_node', full_name='org.xrpl.rpc.v1.SignerList.owner_node', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_entries', full_name='org.xrpl.rpc.v1.SignerList.signer_entries', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_list_id', full_name='org.xrpl.rpc.v1.SignerList.signer_list_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signer_quorum', full_name='org.xrpl.rpc.v1.SignerList.signer_quorum', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6651,
  serialized_end=7084,
)

_LEDGEROBJECT.fields_by_name['account_root'].message_type = _ACCOUNTROOT
_LEDGEROBJECT.fields_by_name['amendments'].message_type = _AMENDMENTS
_LEDGEROBJECT.fields_by_name['check'].message_type = _CHECK
_LEDGEROBJECT.fields_by_name['deposit_preauth'].message_type = _DEPOSITPREAUTHOBJECT
_LEDGEROBJECT.fields_by_name['directory_node'].message_type = _DIRECTORYNODE
_LEDGEROBJECT.fields_by_name['escrow'].message_type = _ESCROW
_LEDGEROBJECT.fields_by_name['fee_settings'].message_type = _FEESETTINGS
_LEDGEROBJECT.fields_by_name['ledger_hashes'].message_type = _LEDGERHASHES
_LEDGEROBJECT.fields_by_name['offer'].message_type = _OFFER
_LEDGEROBJECT.fields_by_name['pay_channel'].message_type = _PAYCHANNEL
_LEDGEROBJECT.fields_by_name['ripple_state'].message_type = _RIPPLESTATE
_LEDGEROBJECT.fields_by_name['signer_list'].message_type = _SIGNERLIST
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['account_root'])
_LEDGEROBJECT.fields_by_name['account_root'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['amendments'])
_LEDGEROBJECT.fields_by_name['amendments'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['check'])
_LEDGEROBJECT.fields_by_name['check'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['deposit_preauth'])
_LEDGEROBJECT.fields_by_name['deposit_preauth'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['directory_node'])
_LEDGEROBJECT.fields_by_name['directory_node'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['escrow'])
_LEDGEROBJECT.fields_by_name['escrow'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['fee_settings'])
_LEDGEROBJECT.fields_by_name['fee_settings'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['ledger_hashes'])
_LEDGEROBJECT.fields_by_name['ledger_hashes'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['offer'])
_LEDGEROBJECT.fields_by_name['offer'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['pay_channel'])
_LEDGEROBJECT.fields_by_name['pay_channel'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['ripple_state'])
_LEDGEROBJECT.fields_by_name['ripple_state'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_LEDGEROBJECT.oneofs_by_name['object'].fields.append(
  _LEDGEROBJECT.fields_by_name['signer_list'])
_LEDGEROBJECT.fields_by_name['signer_list'].containing_oneof = _LEDGEROBJECT.oneofs_by_name['object']
_ACCOUNTROOT.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_ACCOUNTROOT.fields_by_name['balance'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BALANCE
_ACCOUNTROOT.fields_by_name['sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SEQUENCE
_ACCOUNTROOT.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_ACCOUNTROOT.fields_by_name['owner_count'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERCOUNT
_ACCOUNTROOT.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_ACCOUNTROOT.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_ACCOUNTROOT.fields_by_name['account_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNTTRANSACTIONID
_ACCOUNTROOT.fields_by_name['domain'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DOMAIN
_ACCOUNTROOT.fields_by_name['email_hash'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EMAILHASH
_ACCOUNTROOT.fields_by_name['message_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._MESSAGEKEY
_ACCOUNTROOT.fields_by_name['regular_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._REGULARKEY
_ACCOUNTROOT.fields_by_name['tick_size'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TICKSIZE
_ACCOUNTROOT.fields_by_name['transfer_rate'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TRANSFERRATE
_AMENDMENTS_AMENDMENT.containing_type = _AMENDMENTS
_AMENDMENTS_MAJORITY.fields_by_name['amendment'].message_type = _AMENDMENTS_AMENDMENT
_AMENDMENTS_MAJORITY.fields_by_name['close_time'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CLOSETIME
_AMENDMENTS_MAJORITY.containing_type = _AMENDMENTS
_AMENDMENTS.fields_by_name['amendments'].message_type = _AMENDMENTS_AMENDMENT
_AMENDMENTS.fields_by_name['majorities'].message_type = _AMENDMENTS_MAJORITY
_AMENDMENTS.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_CHECK.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_CHECK.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_CHECK.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_CHECK.fields_by_name['owner_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERNODE
_CHECK.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_CHECK.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_CHECK.fields_by_name['send_max'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SENDMAX
_CHECK.fields_by_name['sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SEQUENCE
_CHECK.fields_by_name['destination_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONNODE
_CHECK.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_CHECK.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_CHECK.fields_by_name['invoice_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INVOICEID
_CHECK.fields_by_name['source_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SOURCETAG
_DEPOSITPREAUTHOBJECT.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_DEPOSITPREAUTHOBJECT.fields_by_name['authorize'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AUTHORIZE
_DEPOSITPREAUTHOBJECT.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_DEPOSITPREAUTHOBJECT.fields_by_name['owner_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERNODE
_DEPOSITPREAUTHOBJECT.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_DEPOSITPREAUTHOBJECT.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_DIRECTORYNODE.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_DIRECTORYNODE.fields_by_name['root_index'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ROOTINDEX
_DIRECTORYNODE.fields_by_name['indexes'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INDEX
_DIRECTORYNODE.fields_by_name['index_next'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INDEXNEXT
_DIRECTORYNODE.fields_by_name['index_previous'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._INDEXPREVIOUS
_DIRECTORYNODE.fields_by_name['owner'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNER
_DIRECTORYNODE.fields_by_name['taker_pays_currency'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERPAYSCURRENCY
_DIRECTORYNODE.fields_by_name['taker_pays_issuer'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERPAYSISSUER
_DIRECTORYNODE.fields_by_name['taker_gets_currency'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERGETSCURRENY
_DIRECTORYNODE.fields_by_name['taker_gets_issuer'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERGETSISSUER
_ESCROW.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_ESCROW.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_ESCROW.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_ESCROW.fields_by_name['condition'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CONDITION
_ESCROW.fields_by_name['cancel_after'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CANCELAFTER
_ESCROW.fields_by_name['finish_after'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FINISHAFTER
_ESCROW.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_ESCROW.fields_by_name['source_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SOURCETAG
_ESCROW.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_ESCROW.fields_by_name['owner_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERNODE
_ESCROW.fields_by_name['destination_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONNODE
_ESCROW.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_ESCROW.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_FEESETTINGS.fields_by_name['base_fee'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BASEFEE
_FEESETTINGS.fields_by_name['reference_fee_units'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._REFERENCEFEEUNITS
_FEESETTINGS.fields_by_name['reserve_base'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._RESERVEBASE
_FEESETTINGS.fields_by_name['reserve_increment'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._RESERVEINCREMENT
_FEESETTINGS.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_LEDGERHASHES.fields_by_name['last_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LASTLEDGERSEQUENCE
_LEDGERHASHES.fields_by_name['hashes'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._HASH
_LEDGERHASHES.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_OFFER.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_OFFER.fields_by_name['sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SEQUENCE
_OFFER.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_OFFER.fields_by_name['taker_pays'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERPAYS
_OFFER.fields_by_name['taker_gets'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._TAKERGETS
_OFFER.fields_by_name['book_directory'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BOOKDIRECTORY
_OFFER.fields_by_name['book_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BOOKNODE
_OFFER.fields_by_name['owner_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERNODE
_OFFER.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_OFFER.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_OFFER.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_PAYCHANNEL.fields_by_name['account'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._ACCOUNT
_PAYCHANNEL.fields_by_name['destination'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATION
_PAYCHANNEL.fields_by_name['amount'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._AMOUNT
_PAYCHANNEL.fields_by_name['balance'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BALANCE
_PAYCHANNEL.fields_by_name['public_key'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PUBLICKEY
_PAYCHANNEL.fields_by_name['settle_delay'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SETTLEDELAY
_PAYCHANNEL.fields_by_name['owner_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERNODE
_PAYCHANNEL.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_PAYCHANNEL.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_PAYCHANNEL.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_PAYCHANNEL.fields_by_name['expiration'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._EXPIRATION
_PAYCHANNEL.fields_by_name['cancel_after'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._CANCELAFTER
_PAYCHANNEL.fields_by_name['source_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SOURCETAG
_PAYCHANNEL.fields_by_name['destination_tag'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._DESTINATIONTAG
_RIPPLESTATE.fields_by_name['balance'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._BALANCE
_RIPPLESTATE.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_RIPPLESTATE.fields_by_name['low_limit'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LOWLIMIT
_RIPPLESTATE.fields_by_name['high_limit'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._HIGHLIMIT
_RIPPLESTATE.fields_by_name['low_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LOWNODE
_RIPPLESTATE.fields_by_name['high_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._HIGHNODE
_RIPPLESTATE.fields_by_name['low_quality_in'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LOWQUALITYIN
_RIPPLESTATE.fields_by_name['low_quality_out'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._LOWQUALITYOUT
_RIPPLESTATE.fields_by_name['high_quality_in'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._HIGHQUALITYIN
_RIPPLESTATE.fields_by_name['high_quality_out'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._HIGHQUALITYOUT
_RIPPLESTATE.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_RIPPLESTATE.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_SIGNERLIST.fields_by_name['flags'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._FLAGS
_SIGNERLIST.fields_by_name['previous_transaction_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONID
_SIGNERLIST.fields_by_name['previous_transaction_ledger_sequence'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._PREVIOUSTRANSACTIONLEDGERSEQUENCE
_SIGNERLIST.fields_by_name['owner_node'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._OWNERNODE
_SIGNERLIST.fields_by_name['signer_entries'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNERENTRY
_SIGNERLIST.fields_by_name['signer_list_id'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNERLISTID
_SIGNERLIST.fields_by_name['signer_quorum'].message_type = org_dot_xrpl_dot_rpc_dot_v1_dot_common__pb2._SIGNERQUORUM
DESCRIPTOR.message_types_by_name['LedgerObject'] = _LEDGEROBJECT
DESCRIPTOR.message_types_by_name['AccountRoot'] = _ACCOUNTROOT
DESCRIPTOR.message_types_by_name['Amendments'] = _AMENDMENTS
DESCRIPTOR.message_types_by_name['Check'] = _CHECK
DESCRIPTOR.message_types_by_name['DepositPreauthObject'] = _DEPOSITPREAUTHOBJECT
DESCRIPTOR.message_types_by_name['DirectoryNode'] = _DIRECTORYNODE
DESCRIPTOR.message_types_by_name['Escrow'] = _ESCROW
DESCRIPTOR.message_types_by_name['FeeSettings'] = _FEESETTINGS
DESCRIPTOR.message_types_by_name['LedgerHashes'] = _LEDGERHASHES
DESCRIPTOR.message_types_by_name['Offer'] = _OFFER
DESCRIPTOR.message_types_by_name['PayChannel'] = _PAYCHANNEL
DESCRIPTOR.message_types_by_name['RippleState'] = _RIPPLESTATE
DESCRIPTOR.message_types_by_name['SignerList'] = _SIGNERLIST
DESCRIPTOR.enum_types_by_name['LedgerEntryType'] = _LEDGERENTRYTYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LedgerObject = _reflection.GeneratedProtocolMessageType('LedgerObject', (_message.Message,), {
  'DESCRIPTOR' : _LEDGEROBJECT,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerObject)
  })
_sym_db.RegisterMessage(LedgerObject)

AccountRoot = _reflection.GeneratedProtocolMessageType('AccountRoot', (_message.Message,), {
  'DESCRIPTOR' : _ACCOUNTROOT,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.AccountRoot)
  })
_sym_db.RegisterMessage(AccountRoot)

Amendments = _reflection.GeneratedProtocolMessageType('Amendments', (_message.Message,), {

  'Amendment' : _reflection.GeneratedProtocolMessageType('Amendment', (_message.Message,), {
    'DESCRIPTOR' : _AMENDMENTS_AMENDMENT,
    '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
    # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Amendments.Amendment)
    })
  ,

  'Majority' : _reflection.GeneratedProtocolMessageType('Majority', (_message.Message,), {
    'DESCRIPTOR' : _AMENDMENTS_MAJORITY,
    '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
    # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Amendments.Majority)
    })
  ,
  'DESCRIPTOR' : _AMENDMENTS,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Amendments)
  })
_sym_db.RegisterMessage(Amendments)
_sym_db.RegisterMessage(Amendments.Amendment)
_sym_db.RegisterMessage(Amendments.Majority)

Check = _reflection.GeneratedProtocolMessageType('Check', (_message.Message,), {
  'DESCRIPTOR' : _CHECK,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Check)
  })
_sym_db.RegisterMessage(Check)

DepositPreauthObject = _reflection.GeneratedProtocolMessageType('DepositPreauthObject', (_message.Message,), {
  'DESCRIPTOR' : _DEPOSITPREAUTHOBJECT,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DepositPreauthObject)
  })
_sym_db.RegisterMessage(DepositPreauthObject)

DirectoryNode = _reflection.GeneratedProtocolMessageType('DirectoryNode', (_message.Message,), {
  'DESCRIPTOR' : _DIRECTORYNODE,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.DirectoryNode)
  })
_sym_db.RegisterMessage(DirectoryNode)

Escrow = _reflection.GeneratedProtocolMessageType('Escrow', (_message.Message,), {
  'DESCRIPTOR' : _ESCROW,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Escrow)
  })
_sym_db.RegisterMessage(Escrow)

FeeSettings = _reflection.GeneratedProtocolMessageType('FeeSettings', (_message.Message,), {
  'DESCRIPTOR' : _FEESETTINGS,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.FeeSettings)
  })
_sym_db.RegisterMessage(FeeSettings)

LedgerHashes = _reflection.GeneratedProtocolMessageType('LedgerHashes', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERHASHES,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerHashes)
  })
_sym_db.RegisterMessage(LedgerHashes)

Offer = _reflection.GeneratedProtocolMessageType('Offer', (_message.Message,), {
  'DESCRIPTOR' : _OFFER,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.Offer)
  })
_sym_db.RegisterMessage(Offer)

PayChannel = _reflection.GeneratedProtocolMessageType('PayChannel', (_message.Message,), {
  'DESCRIPTOR' : _PAYCHANNEL,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.PayChannel)
  })
_sym_db.RegisterMessage(PayChannel)

RippleState = _reflection.GeneratedProtocolMessageType('RippleState', (_message.Message,), {
  'DESCRIPTOR' : _RIPPLESTATE,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.RippleState)
  })
_sym_db.RegisterMessage(RippleState)

SignerList = _reflection.GeneratedProtocolMessageType('SignerList', (_message.Message,), {
  'DESCRIPTOR' : _SIGNERLIST,
  '__module__' : 'org.xrpl.rpc.v1.ledger_objects_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.SignerList)
  })
_sym_db.RegisterMessage(SignerList)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# @generated by generate_proto_mypy_stubs.py.  Do not edit!
import sys
from google.protobuf.descriptor import (
    Descriptor as google___protobuf___descriptor___Descriptor,
)

from google.protobuf.message import (
    Message as google___protobuf___message___Message,
)

from .meta_pb2 import (
    TransactionResult as org___xrpl___rpc___v1___meta_pb2___TransactionResult,
)

from typing import (
    Optional as typing___Optional,
    Text as typing___Text,
    Union as typing___Union,
)

from typing_extensions import (
    Literal as typing_extensions___Literal,
)


builtin___bool = bool
builtin___bytes = bytes
builtin___float = float
builtin___int = int
if sys.version_info < (3,):
    builtin___buffer = buffer
    builtin___unicode = unicode


class SubmitTransactionRequest(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    signed_transaction = ... # type: builtin___bytes
    fail_hard = ... # type: builtin___bool

    def __init__(self,
        *,
        signed_transaction : typing___Optional[builtin___bytes] = None,
        fail_hard : typing___Optional[builtin___bool] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SubmitTransactionRequest: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SubmitTransactionRequest: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def ClearField(self, field_name: typing_extensions___Literal[u"fail_hard",u"signed_transaction"]) -> None: ...
    else:
        def ClearField(self, field_name: typing_extensions___Literal[u"fail_hard",b"fail_hard",u"signed_transaction",b"signed_transaction"]) -> None: ...

class SubmitTransactionResponse(google___protobuf___message___Message):
    DESCRIPTOR: google___protobuf___descriptor___Descriptor = ...
    engine_result_code = ... # type: builtin___int
    engine_result_message = ... # type: typing___Text
    hash = ... # type: builtin___bytes

    @property
    def engine_result(self) -> org___xrpl___rpc___v1___meta_pb2___TransactionResult: ...

    def __init__(self,
        *,
        engine_result : typing___Optional[org___xrpl___rpc___v1___meta_pb2___TransactionResult] = None,
        engine_result_code : typing___Optional[builtin___int] = None,
        engine_result_message : typing___Optional[typing___Text] = None,
        hash : typing___Optional[builtin___bytes] = None,
        ) -> None: ...
    if sys.version_info >= (3,):
        @classmethod
        def FromString(cls, s: builtin___bytes) -> SubmitTransactionResponse: ...
    else:
        @classmethod
        def FromString(cls, s: typing___Union[builtin___bytes, builtin___buffer, builtin___unicode]) -> SubmitTransactionResponse: ...
    def MergeFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    def CopyFrom(self, other_msg: google___protobuf___message___Message) -> None: ...
    if sys.version_info >= (3,):
        def HasField(self, field_name: typing_extensions___Literal[u"engine_result"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"engine_result",u"engine_result_code",u"engine_result_message",u"hash"]) -> None: ...
    else:
        def HasField(self, field_name: typing_extensions___Literal[u"engine_result",b"engine_result"]) -> builtin___bool: ...
        def ClearField(self, field_name: typing_extensions___Literal[u"engine_result",b"engine_result",u"engine_result_code",b"engine_result_code",u"engine_result_message",b"engine_result_message",u"hash",b"hash"]) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: org/xrpl/rpc/v1/ledger.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='org/xrpl/rpc/v1/ledger.proto',
  package='org.xrpl.rpc.v1',
  syntax='proto3',
  serialized_options=b'\n\017org.xrpl.rpc.v1P\001',
  serialized_pb=b'\n\x1corg/xrpl/rpc/v1/ledger.proto\x12\x0forg.xrpl.rpc.v1\"\xe7\x01\n\x0fLedgerSpecifier\x12=\n\x08shortcut\x18\x01 \x01(\x0e\x32).org.xrpl.rpc.v1.LedgerSpecifier.ShortcutH\x00\x12\x12\n\x08sequence\x18\x02 \x01(\rH\x00\x12\x0e\n\x04hash\x18\x03 \x01(\x0cH\x00\"g\n\x08Shortcut\x12\x18\n\x14SHORTCUT_UNSPECIFIED\x10\x00\x12\x16\n\x12SHORTCUT_VALIDATED\x10\x01\x12\x13\n\x0fSHORTCUT_CLOSED\x10\x02\x12\x14\n\x10SHORTCUT_CURRENT\x10\x03\x42\x08\n\x06ledger\"A\n\x0bLedgerRange\x12\x18\n\x10ledger_index_min\x18\x01 \x01(\r\x12\x18\n\x10ledger_index_max\x18\x02 \x01(\rB\x13\n\x0forg.xrpl.rpc.v1P\x01\x62\x06proto3'
)



_LEDGERSPECIFIER_SHORTCUT = _descriptor.EnumDescriptor(
  name='Shortcut',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier.Shortcut',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_VALIDATED', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CLOSED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SHORTCUT_CURRENT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=168,
  serialized_end=271,
)
_sym_db.RegisterEnumDescriptor(_LEDGERSPECIFIER_SHORTCUT)


_LEDGERSPECIFIER = _descriptor.Descriptor(
  name='LedgerSpecifier',
  full_name='org.xrpl.rpc.v1.LedgerSpecifier',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='shortcut', full_name='org.xrpl.rpc.v1.LedgerSpecifier.shortcut', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sequence', full_name='org.xrpl.rpc.v1.LedgerSpecifier.sequence', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hash', full_name='org.xrpl.rpc.v1.LedgerSpecifier.hash', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LEDGERSPECIFIER_SHORTCUT,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='ledger', full_name='org.xrpl.rpc.v1.LedgerSpecifier.ledger',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=50,
  serialized_end=281,
)


_LEDGERRANGE = _descriptor.Descriptor(
  name='LedgerRange',
  full_name='org.xrpl.rpc.v1.LedgerRange',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ledger_index_min', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_min', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ledger_index_max', full_name='org.xrpl.rpc.v1.LedgerRange.ledger_index_max', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=348,
)

_LEDGERSPECIFIER.fields_by_name['shortcut'].enum_type = _LEDGERSPECIFIER_SHORTCUT
_LEDGERSPECIFIER_SHORTCUT.containing_type = _LEDGERSPECIFIER
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['shortcut'])
_LEDGERSPECIFIER.fields_by_name['shortcut'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['sequence'])
_LEDGERSPECIFIER.fields_by_name['sequence'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
_LEDGERSPECIFIER.oneofs_by_name['ledger'].fields.append(
  _LEDGERSPECIFIER.fields_by_name['hash'])
_LEDGERSPECIFIER.fields_by_name['hash'].containing_oneof = _LEDGERSPECIFIER.oneofs_by_name['ledger']
DESCRIPTOR.message_types_by_name['LedgerSpecifier'] = _LEDGERSPECIFIER
DESCRIPTOR.message_types_by_name['LedgerRange'] = _LEDGERRANGE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LedgerSpecifier = _reflection.GeneratedProtocolMessageType('LedgerSpecifier', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERSPECIFIER,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerSpecifier)
  })
_sym_db.RegisterMessage(LedgerSpecifier)

LedgerRange = _reflection.GeneratedProtocolMessageType('LedgerRange', (_message.Message,), {
  'DESCRIPTOR' : _LEDGERRANGE,
  '__module__' : 'org.xrpl.rpc.v1.ledger_pb2'
  # @@protoc_insertion_point(class_scope:org.xrpl.rpc.v1.LedgerRange)
  })
_sym_db.RegisterMessage(LedgerRange)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
